package net.knarcraft.minecraftserverlauncher.server.servertypes;

/**
 * Contains the bare minimum to be a functional server type.
 *
 * @author Kristian Knarvik <kristian.knarvik@knett.no>
 * @version 1.0.0
 * @since 1.0.0
 */
public abstract class AbstractServerType implements ServerType {
    final String downloadURL;
    private final String typeName;
    private final boolean isProxy;
    private final String[] versions;

    /**
     * Instantiates a new server type
     *
     * @param typeName    <p>The typeName of the server type</p>
     * @param isProxy     <p>Whether this server type is a proxy server</p>
     * @param versions    <p>A list of one or more server versions for the type</p>
     * @param downloadURL <p>The URL used for downloading .jar files</p>
     */
    AbstractServerType(String typeName, boolean isProxy, String[] versions, String downloadURL) {
        this.typeName = typeName;
        this.isProxy = isProxy;
        this.versions = versions;
        this.downloadURL = downloadURL;
    }

    @Override
    public String getName() {
        return this.typeName;
    }

    @Override
    public boolean isProxy() {
        return this.isProxy;
    }

    @Override
    public String[] getVersions() {
        return this.versions;
    }

}