package net.knarcraft.minecraftserverlauncher.server.servertypes;

import net.knarcraft.minecraftserverlauncher.server.ServerVersionContainer;
import net.knarcraft.minecraftserverlauncher.utility.CommonFunctions;

import java.io.File;
import java.io.IOException;
import java.nio.file.Paths;

import static net.knarcraft.minecraftserverlauncher.utility.CommonFunctions.downloadFile;

public class SpongeVanilla extends AbstractServerType {

    private String versionURL;
    private String srcStart;
    private String srcEnd;
    private String downloadURLPart;

    /**
     * Instantiates a new SpongeVanilla server type
     *
     * @param typeName        <p>The name of this server type</p>
     * @param isProxy         <p>Whether this server type is a proxy server</p>
     * @param versions        <p>Available versions for this server type</p>
     * @param versionURL      <p>The URL used for downloading the version document</p>
     * @param srcStart        <p>The string to search for to determine newest version</p>
     * @param srcEnd          <p>The string marking the end of the newest version statement</p>
     * @param downloadURL     <p>The URL used for downloading the new file</p>
     * @param downloadURLPart <p>A string used after the download url as an additional part of the URL</p>
     */
    public SpongeVanilla(String typeName, boolean isProxy, String[] versions, String versionURL, String srcStart, String srcEnd,
                         String downloadURL, String downloadURLPart) {
        super(typeName, isProxy, versions, downloadURL);
        this.versionURL = versionURL;
        this.srcStart = srcStart;
        this.srcEnd = srcEnd;
        this.downloadURLPart = downloadURLPart;
    }

    @Override
    public boolean downloadJar(String folder, String version) throws IOException {
        ServerVersionContainer versionContainer = ServerVersionContainer.getInstance();
        String file = this.getName() + version + ".jar";
        File filePath = new File(folder + file);

        String versionText = CommonFunctions.readFile(versionURL + version);
        String newestVersion = CommonFunctions.stringBetween(versionText, srcStart, srcEnd);

        String jarURL = downloadURL + newestVersion + downloadURLPart + newestVersion + ".jar";

        String oldVersion = versionContainer.getSpongeVanillaVersion(version);
        //The file is already the newest version
        if (filePath.isFile() && newestVersion.equals(oldVersion)) {
            return true;
        }
        //The new jar file could not be downloaded
        if (!downloadFile(jarURL, Paths.get(filePath.toURI()))) {
            return false;
        }
        versionContainer.setSpongeVanillaVersion(version, newestVersion);
        return true;
    }
}
